signInForm property

SignInForm? signInForm
final

The form displayed during sign in.

By default, the authenticator will use the amplify config to build this view with the required attributes and validation.

To customize which fields are displayed, the order they are displayed in, or the field validation, provide a custom sign in form via SignInForm.custom().

To fully customize the UI, see authenticatorBuilder

Implementation

final SignInForm? signInForm;