includeDefaultSocialProviders property
Whether to include buttons for the configured social providers.
Implementation
final bool includeDefaultSocialProviders;
Whether to include buttons for the configured social providers.
final bool includeDefaultSocialProviders;