password property

String get password

The value for the password form field

This value will be used during sign up, sign in, or other actions that required the password

Implementation

String get password => _password;
set password (String value)

Implementation

set password(String value) {
  _password = value.trim();
  notifyListeners();
}