backTo method
Label of button to return to the Sign In step.
Implementation
String backTo(BuildContext context, AuthenticatorStep previousStep) {
return AuthenticatorLocalizations.buttonsOf(
context,
).backTo(previousStep.name);
}
Label of button to return to the Sign In step.
String backTo(BuildContext context, AuthenticatorStep previousStep) {
return AuthenticatorLocalizations.buttonsOf(
context,
).backTo(previousStep.name);
}