confirmResetPassword method
Label of button to confirm the reset of a user's password
Implementation
String confirmResetPassword(BuildContext context) {
return AuthenticatorLocalizations.buttonsOf(context).confirmResetPassword;
}
Label of button to confirm the reset of a user's password
String confirmResetPassword(BuildContext context) {
return AuthenticatorLocalizations.buttonsOf(context).confirmResetPassword;
}