verify method
Label of button to verify a user after sign in
Implementation
String verify(BuildContext context) {
return AuthenticatorLocalizations.buttonsOf(context).verify;
}
Label of button to verify a user after sign in
String verify(BuildContext context) {
return AuthenticatorLocalizations.buttonsOf(context).verify;
}