usernameRequires method
Returns the text displayed when the username requirements are not met
Implementation
String usernameRequires(BuildContext context) {
return AuthenticatorLocalizations.inputsOf(context).usernameRequirements;
}
Returns the text displayed when the username requirements are not met
String usernameRequires(BuildContext context) {
return AuthenticatorLocalizations.inputsOf(context).usernameRequirements;
}