totpStep1Body method
The Body text for step first step of TOTP setup
Implementation
String totpStep1Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep1Body;
}
The Body text for step first step of TOTP setup
String totpStep1Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep1Body;
}