totpStep2Body method
The Body text for step second step of TOTP setup
Implementation
String totpStep2Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep2Body;
}
The Body text for step second step of TOTP setup
String totpStep2Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep2Body;
}