totpStep3Body method
The Body text for step three step of TOTP setup
Implementation
String totpStep3Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep3Body;
}
The Body text for step three step of TOTP setup
String totpStep3Body(BuildContext context) {
return AuthenticatorLocalizations.instructionsOf(context).totpStep3Body;
}