usernameSelection property
UsernameSelection
get
usernameSelection
The username type to use during sign up and sign in for configurations that allow email OR phone number.
Defaults to UsernameSelection.email.
The value has no meaning for Auth configurations that do not allow for email OR phone number to be used as username.
Implementation
UsernameSelection get usernameSelection => _usernameSelection;
set
usernameSelection
(UsernameSelection value)
Implementation
set usernameSelection(UsernameSelection value) {
_usernameSelection = value;
notifyListeners();
}